﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Diagnostics;
using Infragistics.Windows.Helpers;
using System.Collections.ObjectModel;
using System.Collections.Specialized;
using Infragistics.Windows.DockManager;
using Infragistics.Windows.Extensions;

namespace TestWindowsApp
{
	/// <summary>
	/// Interaction logic for Window_DockBinding.xaml
	/// </summary>
	public partial class Window_DockBinding : Window
	{
		#region Constructor
		public Window_DockBinding()
		{
			_splitItems = SampleHelper.CreatePeopleList();
			_splitItems.CollectionChanged += new NotifyCollectionChangedEventHandler(OnSplitItemsChanged);

			_documents = SampleHelper.CreatePeopleList();
			_documents.CollectionChanged += new NotifyCollectionChangedEventHandler(OnDocumentsChanged);

			InitializeComponent();
		} 
		#endregion //Constructor

		#region Properties

		private ObservableCollection<Person> _documents;
		public ObservableCollection<Person> Documents
		{
			get { return _documents; }
		}

		private ObservableCollection<Person> _splitItems;
		public ObservableCollection<Person> SplitItems
		{
			get { return _splitItems; }
		} 

		#endregion //Properties

		#region Methods

		#region AddToEventLog
		private void AddToEventLog(string prefix, NotifyCollectionChangedEventArgs e)
		{
			StringBuilder sb = new StringBuilder();
			sb.AppendFormat("{0} Action={1}", prefix, e.Action);

			switch (e.Action)
			{
				case NotifyCollectionChangedAction.Add:
					sb.Append(" New Items:");
					foreach (object item in e.NewItems)
						sb.Append(item);
					break;
				case NotifyCollectionChangedAction.Move:
					sb.AppendFormat("OldIndex={0}, NewIndex={1}", e.OldStartingIndex, e.NewStartingIndex);
					break;
				case NotifyCollectionChangedAction.Remove:
					sb.Append(" Old Items:");
					foreach (object item in e.OldItems)
						sb.Append(item);
					break;
				case NotifyCollectionChangedAction.Replace:
					sb.AppendFormat("OldItem={0}, NewItem={1}", e.OldItems[0], e.NewItems[0]);
					break;
			}

			this.AddToEventLog(sb.ToString());
		}

		private void AddToEventLog(string prefix, Infragistics.Windows.Extensions.InitializeContentPaneEventArgs e)
		{
			StringBuilder sb = new StringBuilder();
			sb.Append(prefix);
			sb.Append("InitializeContentPane  Item=");
			sb.Append(ContentPaneFactory.GetItemForContainer(e.Pane));
			this.AddToEventLog(sb.ToString());
		}

		private void AddToEventLog(string message)
		{
			// skip the initialization related messages
			if (!this.IsLoaded)
				return;

			int index = this.lstEventLog.Items.Add(message);
			this.lstEventLog.SelectedIndex = index;
			this.lstEventLog.ScrollIntoView(message);
		}
		#endregion //AddToEventLog

		#endregion //Methods

		#region Event Sinks

		#region OnDocumentsChanged
		void OnDocumentsChanged(object sender, NotifyCollectionChangedEventArgs e)
		{
			this.AddToEventLog("Documents: ", e);
		}
		#endregion //OnDocumentsChanged

		#region OnSplitItemsChanged
		void OnSplitItemsChanged(object sender, NotifyCollectionChangedEventArgs e)
		{
			this.AddToEventLog("SplitItems: ", e);
		}
		#endregion //OnSplitItemsChanged

		#region Hyperlink_RequestNavigate
		private void Hyperlink_RequestNavigate(object sender, System.Windows.Navigation.RequestNavigateEventArgs e)
		{
			ProcessStartInfo psi = new ProcessStartInfo();
			psi.FileName = e.Uri.ToString();

			Process.Start(psi);
		}
		#endregion //Hyperlink_RequestNavigate

		#region mnuShowHidden_Click
		private void mnuShowHidden_Click(object sender, RoutedEventArgs e)
		{
			List<ContentPane> panes = dockManager.GetPanes(PaneNavigationOrder.ActivationOrder).ToList();

			foreach (ContentPane pane in panes)
				pane.Visibility = Visibility.Visible;
		}
		#endregion //mnuShowHidden_Click

		#region mnuAddToSplit_Click
		private void mnuAddToSplit_Click(object sender, RoutedEventArgs e)
		{
			this.SplitItems.Add(SampleHelper.CreatePerson());
		}
		#endregion //mnuAddToSplit_Click

		#region mnuAddDocument_Click
		private void mnuAddDocument_Click(object sender, RoutedEventArgs e)
		{
			this.Documents.Add(SampleHelper.CreatePerson());
		}
		#endregion //mnuAddDocument_Click

		private void fromXml_InitializeContentPane(object sender, Infragistics.Windows.Extensions.InitializeContentPaneEventArgs e)
		{
			this.AddToEventLog("fromXml: ", e);
		}

		private void splitLeft_InitializeContentPane(object sender, Infragistics.Windows.Extensions.InitializeContentPaneEventArgs e)
		{
			this.AddToEventLog("splitLeft: ", e);
		}

		private void DocumentContentHost_InitializeContentPane(object sender, Infragistics.Windows.Extensions.InitializeContentPaneEventArgs e)
		{
			this.AddToEventLog("DCH: ", e);
		}

		#endregion //Event Sinks
	}
}
